==> qtjambi-networkauth-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiNetworkAuth/QAbstractOAuth_ModifyParametersFunction_shell.cpp <==
#include "QAbstractOAuth_ModifyParametersFunction_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QAbstractOAuth_ModifyParametersFunction(void *ptr,bool) { delete reinterpret_cast<QAbstractOAuth$ModifyParametersFunction_shell*>(ptr); }


QAbstractOAuth$ModifyParametersFunction_shell::QAbstractOAuth$ModifyParametersFunction_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAbstractOAuth$ModifyParametersFunction_shell::QAbstractOAuth$ModifyParametersFunction_shell()")
    QAbstractOAuth$ModifyParametersFunction_shell::__shell()->constructed(typeid(QAbstractOAuth::ModifyParametersFunction));
}

// emitting (writeShellDestructor)
QAbstractOAuth$ModifyParametersFunction_shell::~QAbstractOAuth$ModifyParametersFunction_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractOAuth$ModifyParametersFunction_shell::~QAbstractOAuth$ModifyParametersFunction_shell()", QAbstractOAuth$ModifyParametersFunction_shell::__shell())
    QAbstractOAuth$ModifyParametersFunction_shell::__shell()->destructed(typeid(QAbstractOAuth::ModifyParametersFunction));
}

// construct QAbstractOAuth$ModifyParametersFunction_shell
void __qt_construct_QAbstractOAuth_ModifyParametersFunction_0(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAbstractOAuth::ModifyParametersFunction")
    new (__qtjambi_ptr) QAbstractOAuth$ModifyParametersFunction_shell();
}
// destruct QAbstractOAuth$ModifyParametersFunction_shell
void __qt_destruct_QAbstractOAuth_ModifyParametersFunction(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractOAuth::ModifyParametersFunction")
    reinterpret_cast<QAbstractOAuth$ModifyParametersFunction_shell*>(ptr)->~QAbstractOAuth$ModifyParametersFunction_shell();
}

void QAbstractOAuth$ModifyParametersFunction_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractOAuth$ModifyParametersFunction_shell*>(ptr)->QAbstractOAuth$ModifyParametersFunction_shell::__shell()->tryDeleteShell(typeid(QAbstractOAuth::ModifyParametersFunction));
}

QtJambiShell* QAbstractOAuth$ModifyParametersFunction_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractOAuth$ModifyParametersFunction_shell) ); }

QAbstractOAuth$ModifyParametersFunction_shell::Functor::Functor(QAbstractOAuth$ModifyParametersFunction_shell& functional) : FunctorBase(typeid(QAbstractOAuth::ModifyParametersFunction), functional) {}

QAbstractOAuth$ModifyParametersFunction_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QAbstractOAuth$ModifyParametersFunction_shell::Functor::~Functor() {}

void QAbstractOAuth$ModifyParametersFunction_shell::Functor::operator()(QAbstractOAuth::Stage arg__1, QMap<QString, QVariant>* arg__2)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_arg__2 = qtjambi_cast<jobject>(env, arg__2);
                    env->CallVoidMethod(__java_this, method_id, __java_arg__1, __java_arg__2);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "QAbstractOAuth::ModifyParametersFunction");
            } QTJAMBI_TRY_END
        }
    }
}

void QAbstractOAuth$ModifyParametersFunction_shell::getFunctional(JNIEnv *, void* result)
{
    *reinterpret_cast<QAbstractOAuth::ModifyParametersFunction*>(result) = Functor(*this);
}

jobject QAbstractOAuth$ModifyParametersFunction_shell::resolveFunctional(JNIEnv * env, const QAbstractOAuth::ModifyParametersFunction* function)
{
    if(function){
        if(const QAbstractOAuth$ModifyParametersFunction_shell::Functor* functor = function->target<QAbstractOAuth$ModifyParametersFunction_shell::Functor>()){
            return functor->getJavaObjectLocalRef(env);
        }
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_auth_QAbstractOAuth_00024ModifyParametersFunction_00024Impl_00024ConcreteWrapper_accept__ILjava_util_Map_2)
(JNIEnv *__jni_env, jobject __this, jint arg__1, jobject arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("ModifyParametersFunction(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        QAbstractOAuth::ModifyParametersFunction* function = QtJambiAPI::convertJavaInterfaceToNative<QAbstractOAuth::ModifyParametersFunction>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        qint32 __qt_arg__1 = qtjambi_cast<qint32>(__jni_env, arg__1);
        QMap<QString, QVariant>*  __qt_arg__2 = qtjambi_cast<QMap<QString, QVariant>* >(__jni_env, __qtjambi_scope, arg__2);
        (*function)(QAbstractOAuth::Stage(__qt_arg__1), __qt_arg__2);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_auth_QAbstractOAuth_00024ModifyParametersFunction_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractOAuth$ModifyParametersFunction_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractOAuth_ModifyParametersFunction_0, sizeof(QAbstractOAuth$ModifyParametersFunction_shell), typeid(QAbstractOAuth::ModifyParametersFunction), &deleter_QAbstractOAuth_ModifyParametersFunction);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

void initialize_meta_info_QAbstractOAuth_ModifyParametersFunction(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QAbstractOAuth::ModifyParametersFunction, QAbstractOAuth$ModifyParametersFunction_shell>("QAbstractOAuth::ModifyParametersFunction", "io/qt/network/auth/QAbstractOAuth$ModifyParametersFunction",
                              &deleter_QAbstractOAuth_ModifyParametersFunction,
                              &__qt_destruct_QAbstractOAuth_ModifyParametersFunction,
                              {ConstructorInfo(&__qt_construct_QAbstractOAuth_ModifyParametersFunction_0, nullptr)},
                              {FunctionInfo("accept", "(Lio/qt/network/auth/QAbstractOAuth$Stage;Ljava/util/Map;)V", FunctionInfo::Abstract)});
}

==> qtjambi-networkauth-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiNetworkAuth/QAbstractOAuth_ModifyParametersFunction_shell.cpp <==
#include "QAbstractOAuth_ModifyParametersFunction_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QAbstractOAuth_ModifyParametersFunction(void *ptr,bool) { delete reinterpret_cast<QAbstractOAuth$ModifyParametersFunction_shell*>(ptr); }


QAbstractOAuth$ModifyParametersFunction_shell::QAbstractOAuth$ModifyParametersFunction_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAbstractOAuth$ModifyParametersFunction_shell::QAbstractOAuth$ModifyParametersFunction_shell()")
    QAbstractOAuth$ModifyParametersFunction_shell::__shell()->constructed(typeid(QAbstractOAuth::ModifyParametersFunction));
}

// emitting (writeShellDestructor)
QAbstractOAuth$ModifyParametersFunction_shell::~QAbstractOAuth$ModifyParametersFunction_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractOAuth$ModifyParametersFunction_shell::~QAbstractOAuth$ModifyParametersFunction_shell()", QAbstractOAuth$ModifyParametersFunction_shell::__shell())
    QAbstractOAuth$ModifyParametersFunction_shell::__shell()->destructed(typeid(QAbstractOAuth::ModifyParametersFunction));
}

// construct QAbstractOAuth$ModifyParametersFunction_shell
void __qt_construct_QAbstractOAuth_ModifyParametersFunction_0(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAbstractOAuth::ModifyParametersFunction")
    new (__qtjambi_ptr) QAbstractOAuth$ModifyParametersFunction_shell();
}
// destruct QAbstractOAuth$ModifyParametersFunction_shell
void __qt_destruct_QAbstractOAuth_ModifyParametersFunction(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractOAuth::ModifyParametersFunction")
    reinterpret_cast<QAbstractOAuth$ModifyParametersFunction_shell*>(ptr)->~QAbstractOAuth$ModifyParametersFunction_shell();
}

void QAbstractOAuth$ModifyParametersFunction_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractOAuth$ModifyParametersFunction_shell*>(ptr)->QAbstractOAuth$ModifyParametersFunction_shell::__shell()->tryDeleteShell(typeid(QAbstractOAuth::ModifyParametersFunction));
}

QtJambiShell* QAbstractOAuth$ModifyParametersFunction_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractOAuth$ModifyParametersFunction_shell) ); }

QAbstractOAuth$ModifyParametersFunction_shell::Functor::Functor(QAbstractOAuth$ModifyParametersFunction_shell& functional) : FunctorBase(typeid(QAbstractOAuth::ModifyParametersFunction), functional) {}

QAbstractOAuth$ModifyParametersFunction_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QAbstractOAuth$ModifyParametersFunction_shell::Functor::~Functor() {}

void QAbstractOAuth$ModifyParametersFunction_shell::Functor::operator()(QAbstractOAuth::Stage arg__1, QMultiMap<QString, QVariant>* arg__2)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_arg__2 = qtjambi_cast<jobject>(env, arg__2);
                    env->CallVoidMethod(__java_this, method_id, __java_arg__1, __java_arg__2);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "QAbstractOAuth::ModifyParametersFunction");
            } QTJAMBI_TRY_END
        }
    }
}

void QAbstractOAuth$ModifyParametersFunction_shell::getFunctional(JNIEnv *, void* result)
{
    *reinterpret_cast<QAbstractOAuth::ModifyParametersFunction*>(result) = Functor(*this);
}

jobject QAbstractOAuth$ModifyParametersFunction_shell::resolveFunctional(JNIEnv * env, const QAbstractOAuth::ModifyParametersFunction* function)
{
    if(function){
        if(const QAbstractOAuth$ModifyParametersFunction_shell::Functor* functor = function->target<QAbstractOAuth$ModifyParametersFunction_shell::Functor>()){
            return functor->getJavaObjectLocalRef(env);
        }
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_auth_QAbstractOAuth_00024ModifyParametersFunction_00024Impl_00024ConcreteWrapper_accept__ILjava_util_Map_2)
(JNIEnv *__jni_env, jobject __this, jint arg__1, jobject arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("ModifyParametersFunction(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        QAbstractOAuth::ModifyParametersFunction* function = QtJambiAPI::convertJavaInterfaceToNative<QAbstractOAuth::ModifyParametersFunction>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        qint32 __qt_arg__1 = qtjambi_cast<qint32>(__jni_env, arg__1);
        QMultiMap<QString, QVariant>*  __qt_arg__2 = qtjambi_cast<QMultiMap<QString, QVariant>* >(__jni_env, __qtjambi_scope, arg__2);
        (*function)(QAbstractOAuth::Stage(__qt_arg__1), __qt_arg__2);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_auth_QAbstractOAuth_00024ModifyParametersFunction_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractOAuth$ModifyParametersFunction_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractOAuth_ModifyParametersFunction_0, sizeof(QAbstractOAuth$ModifyParametersFunction_shell), typeid(QAbstractOAuth::ModifyParametersFunction), &deleter_QAbstractOAuth_ModifyParametersFunction);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

void initialize_meta_info_QAbstractOAuth_ModifyParametersFunction(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QAbstractOAuth::ModifyParametersFunction, QAbstractOAuth$ModifyParametersFunction_shell>("QAbstractOAuth::ModifyParametersFunction", "io/qt/network/auth/QAbstractOAuth$ModifyParametersFunction",
                              &deleter_QAbstractOAuth_ModifyParametersFunction,
                              &__qt_destruct_QAbstractOAuth_ModifyParametersFunction,
                              {ConstructorInfo(&__qt_construct_QAbstractOAuth_ModifyParametersFunction_0, nullptr)},
                              {FunctionInfo("accept", "(Lio/qt/network/auth/QAbstractOAuth$Stage;Ljava/util/Map;)V", FunctionInfo::Abstract)});
}
